@@ -1,4 +1,5 @@
 # -*- coding: utf-8 -*-
+from plone.formwidget.geolocation import _
 from plone.formwidget.geolocation.interfaces import IGeolocationSettings
 from plone.app.registry.browser import controlpanel
 
@@ -9,8 +10,8 @@ class GeolocationControlPanelForm(controlpanel.RegistryEditForm):
     schema = IGeolocationSettings
     schema_prefix = "geolocation"
 
-    label = u"Geolocation Settings"
-    description = "Settings for Maps and API Keys."
+    label = _(u"Geolocation Settings")
+    description = _("Settings for Maps and API Keys.")
 
 
 class GeolocationControlPanel(controlpanel.ControlPanelFormWrapper):
